"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullAdapter = exports.BullJobAdapter = void 0;
const queue_1 = require("./queue");
class BullJobAdapter extends queue_1.Job {
    constructor(_job, _queue) {
        super();
        this._job = _job;
        this._queue = _queue;
    }
    get queue() {
        return this._queue;
    }
    get id() {
        return String(this._job.id);
    }
    get name() {
        return this._job.name;
    }
    get data() {
        return this._job.data;
    }
    get returnvalue() {
        return this._job.returnvalue;
    }
    get progress() {
        return this._job.progress();
    }
    get attemptsMade() {
        return this._job.attemptsMade;
    }
    get failedReason() {
        return this._job.failedReason;
    }
    get stacktrace() {
        return this._job.stacktrace;
    }
    get opts() {
        return this._job.opts;
    }
    get processedOn() {
        return this._job.processedOn;
    }
    get finishedOn() {
        return this._job.finishedOn;
    }
    get timestamp() {
        return this._job.timestamp;
    }
    getState() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.getState();
        });
    }
    moveToCompleted(returnValue) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.moveToCompleted(returnValue);
        });
    }
    moveToFailed(reason) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.moveToFailed(reason);
        });
    }
    promote() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.promote();
        });
    }
    discard() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.discard();
        });
    }
    update(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.update(data);
        });
    }
    retry() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.retry();
        });
    }
    remove() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.remove();
        });
    }
    log(row) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.log(row);
        });
    }
}
exports.BullJobAdapter = BullJobAdapter;
class BullAdapter extends queue_1.Queue {
    constructor(_queue) {
        super();
        this._queue = _queue;
        this._id = Buffer.from(this._queue.clientName()).toString('base64');
    }
    // getters
    get provider() {
        return queue_1.QueueProvider.Bull;
    }
    get client() {
        return Promise.resolve(this._queue.client);
    }
    get id() {
        return this._id;
    }
    get name() {
        return this._queue.name;
    }
    get token() {
        return '';
    }
    // setters
    set onGlobalJobCompletion(callback) {
        const oldCb = this._globalJobCompletionCb;
        if (oldCb) {
            this._queue.off('global:completed', oldCb);
        }
        this._globalJobCompletionCb = callback;
        if (callback) {
            this._queue.on('global:completed', callback);
        }
    }
    // public methods
    toKey(queueType) {
        return this._queue.toKey(queueType);
    }
    count() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.count();
        });
    }
    add(name, data, opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const job = yield this._queue.add(name, data, opts);
            return this.normalizeJob(job);
        });
    }
    pause(isLocal, doNotWaitActive) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.pause(isLocal, doNotWaitActive);
        });
    }
    resume(isLocal) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.resume(isLocal);
        });
    }
    clean(grace, status, limit) {
        return __awaiter(this, void 0, void 0, function* () {
            const jobs = yield this._queue.clean(grace, status, limit);
            return jobs.map((job) => String(job.id));
        });
    }
    empty() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.empty();
        });
    }
    isPaused() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.isPaused();
        });
    }
    getJob(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const job = yield this._queue.getJob(id);
            if (job) {
                return this.normalizeJob(job);
            }
        });
    }
    getJobs(status, start, end, asc) {
        return __awaiter(this, void 0, void 0, function* () {
            const jobs = yield this._queue.getJobs([status], start, end, asc);
            return jobs.map((job) => this.normalizeJob(job));
        });
    }
    getJobCounts() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getJobCounts();
        });
    }
    getActiveCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getActiveCount();
        });
    }
    getCompletedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getCompletedCount();
        });
    }
    getFailedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getFailedCount();
        });
    }
    getDelayedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getDelayedCount();
        });
    }
    getWaitingCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getWaitingCount();
        });
    }
    getPausedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getPausedCount();
        });
    }
    removeJobs(pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.removeJobs(pattern);
        });
    }
    getJobLogs(jobId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getJobLogs(jobId);
        });
    }
    close(doNotWaitJobs) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.close(doNotWaitJobs);
        });
    }
    // private methods
    normalizeJob(job) {
        return new BullJobAdapter(job, this);
    }
}
exports.BullAdapter = BullAdapter;
//# sourceMappingURL=bull-adapter.js.map