"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullMQAdapter = exports.BullMQJobAdapter = void 0;
const bullmq_1 = require("bullmq");
const queue_1 = require("./queue");
class BullMQJobAdapter extends queue_1.Job {
    constructor(_job, _queue) {
        super();
        this._job = _job;
        this._queue = _queue;
    }
    // getters
    get queue() {
        return this._queue;
    }
    get id() {
        return String(this._job.id);
    }
    get name() {
        return this._job.name;
    }
    get data() {
        return this._job.data;
    }
    get returnvalue() {
        return this._job.returnvalue;
    }
    get progress() {
        const progress = this._job.progress;
        if (typeof progress === 'number') {
            return progress;
        }
        return 0;
    }
    get attemptsMade() {
        return this._job.attemptsMade;
    }
    get failedReason() {
        return this._job.failedReason;
    }
    get stacktrace() {
        return this._job.stacktrace;
    }
    get opts() {
        return this._job.opts;
    }
    get processedOn() {
        return this._job.processedOn;
    }
    get finishedOn() {
        return this._job.finishedOn;
    }
    get timestamp() {
        return this._job.timestamp;
    }
    getState() {
        return __awaiter(this, void 0, void 0, function* () {
            const status = yield this._job.getState();
            return status;
        });
    }
    moveToCompleted(returnValue) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.moveToCompleted(returnValue, this._queue.token);
        });
    }
    moveToFailed(reason) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.moveToFailed(reason, this._queue.token);
        });
    }
    promote() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.promote();
        });
    }
    discard() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.discard();
        });
    }
    update(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.update(data);
        });
    }
    retry() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.retry();
        });
    }
    remove() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._job.remove();
        });
    }
    log(row) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._job.log(row);
        });
    }
}
exports.BullMQJobAdapter = BullMQJobAdapter;
class BullMQAdapter extends queue_1.Queue {
    constructor(_queue) {
        var _a;
        super();
        this._queue = _queue;
        this._id = Buffer.from(((_a = this._queue.opts.prefix) !== null && _a !== void 0 ? _a : 'bullmq') + this.name).toString('base64');
    }
    // getters
    get provider() {
        return queue_1.QueueProvider.Bullmq;
    }
    get queueEvents() {
        if (!this._queueEvents) {
            this._queueEvents = new bullmq_1.QueueEvents(this._queue.name, this._queue.opts);
        }
        return this._queueEvents;
    }
    get client() {
        return this._queue.client;
    }
    get id() {
        return this._id;
    }
    get name() {
        return this._queue.name;
    }
    get token() {
        return this._queue.token;
    }
    // setters
    set onGlobalJobCompletion(callback) {
        const oldCb = this._globalJobCompletionCb;
        if (oldCb) {
            this.queueEvents.off('completed', oldCb);
        }
        if (callback) {
            const normalizedCallback = (value) => {
                callback(value.jobId);
            };
            this._globalJobCompletionCb = normalizedCallback;
            this.queueEvents.on('completed', normalizedCallback);
        }
        else {
            this._globalJobCompletionCb = undefined;
        }
    }
    // public methods
    toKey(queueType) {
        return this._queue.toKey(queueType);
    }
    count() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.count();
        });
    }
    add(name, data, opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const job = yield this._queue.add(name, data, opts);
            return this.normalizeJob(job);
        });
    }
    pause() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.pause();
        });
    }
    resume() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.resume();
        });
    }
    clean(grace, status, limit = Number.MAX_SAFE_INTEGER) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this._queue.clean(grace, limit, status);
        });
    }
    empty() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.drain();
        });
    }
    isPaused() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.isPaused();
        });
    }
    getJob(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const job = yield this._queue.getJob(id);
            if (job) {
                return this.normalizeJob(job);
            }
        });
    }
    getJobs(types, start, end, asc) {
        return __awaiter(this, void 0, void 0, function* () {
            const jobs = yield this._queue.getJobs(types, start, end, asc);
            return jobs.map((job) => this.normalizeJob(job));
        });
    }
    getJobCounts() {
        return __awaiter(this, void 0, void 0, function* () {
            const counts = yield this._queue.getJobCounts('active', 'completed', 'failed', 'delayed', 'waiting', 'paused');
            return counts;
        });
    }
    getActiveCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getActiveCount();
        });
    }
    getCompletedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getCompletedCount();
        });
    }
    getFailedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getFailedCount();
        });
    }
    getDelayedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getDelayedCount();
        });
    }
    getWaitingCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getWaitingCount();
        });
    }
    getPausedCount() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getJobCountByTypes('paused');
        });
    }
    removeJobs() {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('Not implemented');
        });
    }
    getJobLogs(jobId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._queue.getJobLogs(jobId);
        });
    }
    close() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._queue.close();
            if (this._queueEvents) {
                yield this._queueEvents.close();
            }
        });
    }
    // private methods
    normalizeJob(job) {
        return new BullMQJobAdapter(job, this);
    }
}
exports.BullMQAdapter = BullMQAdapter;
//# sourceMappingURL=bullmq-adapter.js.map